**[Guiding principle]({{path '../../docs/documentation/design-principles.html'}}):** Only include elements that have a purpose.

## General icon guidance

Icons are a visual representation of **a single and simple object, action or idea**. If you need to communicate more complicated concepts, consider an illustration or infographic. 

### The Ontario Design System icon library

The Ontario Design System icon library is made up of two sets:
- [Primary]({{path './icons-primary.html'}}) – these represent the most commonly used concepts on our services (such as phone, menu, search)
- [Secondary]({{path './icons-secondary.html'}}) – these represent concepts that are used often but not as frequently (such as attach, print, map pin)

#### If you need a different icon 

If the concept you need to represent isn’t already in our icon library, you can choose one from the Google Material Design:
- [icon library](https://material.io/resources/icons/?style=baseline) (use the filled versions)
- [community-led iconography library](https://materialdesignicons.com/)

Please let the [design system team]({{path '../../docs/give-feedback.html'}}) know any time you need an icon that isn’t in our icon library. If we find the same ones are being commonly used, we’ll consider adding them to the library.

<hr>

## Why we chose these icons
The Ontario Design System follows the [Material Design system icon design principles](https://material.io/design/iconography/system-icons.html) and uses icons from [Material Design’s icon library](https://material.io/tools/icons/?style=baseline).

We’ve chosen the icons for our library based on [proven best practices](https://www.nngroup.com/articles/icon-usability/) that all icons we use must be:
* a visual representation of **a single** object, action, or idea
* easily **recognizable and understandable**
* likely to be **interpreted in the same way** by users
* used to represent **“universal recognition”** as opposed to “universal representation”
    * for example, a wheelchair is often used for accessibility even though it does not represent all types of disabilities
* **useful**
    * icons should help guide the user to accomplish their task – **don’t use icons purely for visual interest**

<hr>

## Primary icon set

These icons represent the most commonly used concepts on our services (such as phone, menu, search).

<a href="#how-to-use-primary-icons">Skip to how to use primary icons.</a>

All icons follow the naming pattern "ontario-icon-_purpose_". You can search for specific icons using your browser’s find command (`ctrl+f` for PC, `⌘+f` for Mac)

<a download href="{{path '../../icons/png/ontario-icons-archive-pngs.zip'}}">Download all icons as PNG</a>

<div class="fractal-table-scroll">

| Icon | Name | Purpose or aliases | Download 
| ---------- | --------- | --------  | ------------------ 
|{{{render '@icons-primary--ontario-icon-accessibility' }}} | ontario-icon-accessibility| Accessibility|<a download href="{{path '../../icons/png/ontario-icon-accessibility.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-accessibility.svg'}}" download="ontario-icon-accessibility.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-add' }}} | ontario-icon-add| Add row, add field|<a download href="{{path '../../icons/png/ontario-icon-add.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-add.svg'}}" download="ontario-icon-add.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-add-alt' }}} | ontario-icon-add-alt| Add row, add field|<a download href="{{path '../../icons/png/ontario-icon-add-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-add-alt.svg'}}" download="ontario-icon-add-alt.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-error' }}} | ontario-icon-alert-error| Error, alert, ! **Note:** Colour must be alert red (#CD0000)|<a download href="{{path '../../icons/png/ontario-icon-alert-error.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-error.svg'}}" download="ontario-icon-alert-error.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-information' }}} | ontario-icon-alert-information| Information, i|<a download href="{{path '../../icons/png/ontario-icon-alert-information.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-information.svg'}}" download="ontario-icon-alert-information.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-success' }}} | ontario-icon-alert-success| Success, confirmation. **Note:** Colour must be success green (#118847)|<a download href="{{path '../../icons/png/ontario-icon-alert-success.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-success.svg'}}" download="ontario-icon-alert-success.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-alert-warning' }}} | ontario-icon-alert-warning| Warning. **Note:** Colour must be warning yellow (#FCAF17)|<a download href="{{path '../../icons/png/ontario-icon-alert-warning.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-alert-warning.svg'}}" download="ontario-icon-alert-warning.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-down' }}} | ontario-icon-chevron-down| Down|<a download href="{{path '../../icons/png/ontario-icon-chevron-down.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-down.svg'}}" download="ontario-icon-chevron-down.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-left' }}} | ontario-icon-chevron-left| Left, back|<a download href="{{path '../../icons/png/ontario-icon-chevron-left.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-left.svg'}}" download="ontario-icon-chevron-left.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-right' }}} | ontario-icon-chevron-right| Right, forward|<a download href="{{path '../../icons/png/ontario-icon-chevron-right.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-right.svg'}}" download="ontario-icon-chevron-right.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-chevron-up' }}} | ontario-icon-chevron-up| Up|<a download href="{{path '../../icons/png/ontario-icon-chevron-up.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-chevron-up.svg'}}" download="ontario-icon-chevron-up.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-close' }}} | ontario-icon-close| Close, escape|<a download href="{{path '../../icons/png/ontario-icon-close.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-close.svg'}}" download="ontario-icon-close.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-collapse' }}} | ontario-icon-collapse| Close accordion, collapse field|<a download href="{{path '../../icons/png/ontario-icon-collapse.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-collapse.svg'}}" download="ontario-icon-collapse.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-credit-card' }}} | ontario-icon-credit-card| Payment|<a download href="{{path '../../icons/png/ontario-icon-credit-card.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-credit-card.svg'}}" download="ontario-icon-credit-card.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-dropdown-arrow' }}} | ontario-icon-dropdown-arrow| Dropdown, select box, dropdown menu, pull-down list, picklist|<a download href="{{path '../../icons/png/ontario-icon-dropdown-arrow.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-dropdown-arrow.svg'}}" download="ontario-icon-dropdown-arrow.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-email' }}} | ontario-icon-email| Email|<a download href="{{path '../../icons/png/ontario-icon-email.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-email.svg'}}" download="ontario-icon-email.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-expand' }}} | ontario-icon-expand| Open accordion, expand field|<a download href="{{path '../../icons/png/ontario-icon-expand.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-expand.svg'}}" download="ontario-icon-expand.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-help' }}} | ontario-icon-help| Help, ?, questions|<a download href="{{path '../../icons/png/ontario-icon-help.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-help.svg'}}" download="ontario-icon-help.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-menu' }}} | ontario-icon-menu| Menu, hamburger menu|<a download href="{{path '../../icons/png/ontario-icon-menu.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-menu.svg'}}" download="ontario-icon-menu.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-new-window' }}} | ontario-icon-new-window| Opens in a new window|<a download href="{{path '../../icons/png/ontario-icon-new-window.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-new-window.svg'}}" download="ontario-icon-new-window.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-phone' }}} | ontario-icon-phone| Phone, call|<a download href="{{path '../../icons/png/ontario-icon-phone.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-phone.svg'}}" download="ontario-icon-phone.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-remove' }}} | ontario-icon-remove| Remove row, remove field|<a download href="{{path '../../icons/png/ontario-icon-remove.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-remove.svg'}}" download="ontario-icon-remove.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-remove-alt' }}} | ontario-icon-remove-alt| Remove row, remove field|<a download href="{{path '../../icons/png/ontario-icon-remove-alt.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-remove-alt.svg'}}" download="ontario-icon-remove-alt.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-search' }}} | ontario-icon-search| Find, search|<a download href="{{path '../../icons/png/ontario-icon-search.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-search.svg'}}" download="ontario-icon-search.svg">SVG</a>
|{{{render '@icons-primary--ontario-icon-tty' }}} | ontario-icon-tty| TTY|<a download href="{{path '../../icons/png/ontario-icon-tty.png'}}">PNG</a> , <a target="_blank" href="{{path '../../icons/svg/ontario-icon-tty.svg'}}" download="ontario-icon-tty.svg">SVG</a>

</div>

<hr>

## <a name="how-to-use-primary-icons"></a> How to use primary icons 

Copy and paste the <abbr title="Scalable Vector Graphics">SVG</abbr> code for the primary icon file into the &lt;head&gt; element of your HTML page. Note that you will need to include the polyfill in order to make sure that icons render properly on IE11

1. Include this html code (which includes the SVG glyphs) on your page: 

{{{render '@inline-code--icons-primary-setup' }}}

2. Add this html code where you want the icon to appear on the page:

{{{render '@inline-code--icons-primary' }}}

3. Add CSS class ontario-icon from the SCSS or Compiled CSS tab to your project's CSS file.

    See the HTML tab for examples.

<hr>

## Help improve this page
If you have other suggestions or advice or any questions on icons, the [design system team]({{path '../../docs/give-feedback.html'}}) would love to hear from you.
